# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class UserNamespaceAuthorizationApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def user_namespace_authorization_create_user_namespace_authorization(self, user_namespace_authorization_create_request, **kwargs):  # noqa: E501
        """createUserNamespaceAuthorization  # noqa: E501

        <p>Creates a new user namespace authorization.</p> <p>The user ID field may be prefixed with a wildcard token character \"*\" to authorize multiple users access to the namespace. The wildcard only works for as a prefix to match the suffix of the user ID. If the wildcard appears anywhere other than the prefix, the user ID must match as-is. For example:</p> <ul> <li>john.doe@domain.com - only authorizes user with ID \"john.doe@domain.com\"</li> <li>*@domain.com - authorizes users that has the suffix \"@domain.com\"</li> <li>* - authorizes all users</li> <li>john.doe* - only authorizes user with ID \"john.doe*\"</li> </ul> <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_create_user_namespace_authorization(user_namespace_authorization_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserNamespaceAuthorizationCreateRequest user_namespace_authorization_create_request: the information needed to create the user namespace authorization (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_create_user_namespace_authorization_with_http_info(user_namespace_authorization_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_create_user_namespace_authorization_with_http_info(user_namespace_authorization_create_request, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_create_user_namespace_authorization_with_http_info(self, user_namespace_authorization_create_request, **kwargs):  # noqa: E501
        """createUserNamespaceAuthorization  # noqa: E501

        <p>Creates a new user namespace authorization.</p> <p>The user ID field may be prefixed with a wildcard token character \"*\" to authorize multiple users access to the namespace. The wildcard only works for as a prefix to match the suffix of the user ID. If the wildcard appears anywhere other than the prefix, the user ID must match as-is. For example:</p> <ul> <li>john.doe@domain.com - only authorizes user with ID \"john.doe@domain.com\"</li> <li>*@domain.com - authorizes users that has the suffix \"@domain.com\"</li> <li>* - authorizes all users</li> <li>john.doe* - only authorizes user with ID \"john.doe*\"</li> </ul> <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_create_user_namespace_authorization_with_http_info(user_namespace_authorization_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserNamespaceAuthorizationCreateRequest user_namespace_authorization_create_request: the information needed to create the user namespace authorization (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_namespace_authorization_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_create_user_namespace_authorization" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_namespace_authorization_create_request' is set
        if ('user_namespace_authorization_create_request' not in local_var_params or
                local_var_params['user_namespace_authorization_create_request'] is None):
            raise ValueError("Missing the required parameter `user_namespace_authorization_create_request` when calling `user_namespace_authorization_create_user_namespace_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_namespace_authorization_create_request' in local_var_params:
            body_params = local_var_params['user_namespace_authorization_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_delete_user_namespace_authorization(self, user_id, namespace, **kwargs):  # noqa: E501
        """deleteUserNamespaceAuthorization  # noqa: E501

        Deletes an existing user namespace authorization by key. <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_delete_user_namespace_authorization(user_id, namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_delete_user_namespace_authorization_with_http_info(user_id, namespace, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_delete_user_namespace_authorization_with_http_info(user_id, namespace, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_delete_user_namespace_authorization_with_http_info(self, user_id, namespace, **kwargs):  # noqa: E501
        """deleteUserNamespaceAuthorization  # noqa: E501

        Deletes an existing user namespace authorization by key. <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_delete_user_namespace_authorization_with_http_info(user_id, namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'namespace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_delete_user_namespace_authorization" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `user_namespace_authorization_delete_user_namespace_authorization`")  # noqa: E501
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `user_namespace_authorization_delete_user_namespace_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_delete_user_namespace_authorizations_by_user_id(self, user_id, **kwargs):  # noqa: E501
        """deleteUserNamespaceAuthorizationsByUserId  # noqa: E501

        Deletes all existing user namespace authorizations for the specified user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_delete_user_namespace_authorizations_by_user_id(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_delete_user_namespace_authorizations_by_user_id_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_delete_user_namespace_authorizations_by_user_id_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_delete_user_namespace_authorizations_by_user_id_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """deleteUserNamespaceAuthorizationsByUserId  # noqa: E501

        Deletes all existing user namespace authorizations for the specified user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_delete_user_namespace_authorizations_by_user_id_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_delete_user_namespace_authorizations_by_user_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `user_namespace_authorization_delete_user_namespace_authorizations_by_user_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/userIds/{userId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorizations',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_get_user_namespace_authorization(self, user_id, namespace, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorization  # noqa: E501

        Gets an existing user namespace authorization by key. <p>Requires READ permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorization(user_id, namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_get_user_namespace_authorization_with_http_info(user_id, namespace, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_get_user_namespace_authorization_with_http_info(user_id, namespace, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_get_user_namespace_authorization_with_http_info(self, user_id, namespace, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorization  # noqa: E501

        Gets an existing user namespace authorization by key. <p>Requires READ permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorization_with_http_info(user_id, namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'namespace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_get_user_namespace_authorization" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `user_namespace_authorization_get_user_namespace_authorization`")  # noqa: E501
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `user_namespace_authorization_get_user_namespace_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_get_user_namespace_authorizations_by_namespace(self, namespace, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorizationsByNamespace  # noqa: E501

        Gets a list of user namespace authorizations for the specified namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorizations_by_namespace(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_get_user_namespace_authorizations_by_namespace_with_http_info(namespace, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_get_user_namespace_authorizations_by_namespace_with_http_info(namespace, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_get_user_namespace_authorizations_by_namespace_with_http_info(self, namespace, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorizationsByNamespace  # noqa: E501

        Gets a list of user namespace authorizations for the specified namespace.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorizations_by_namespace_with_http_info(namespace, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str namespace: the namespace (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['namespace']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_get_user_namespace_authorizations_by_namespace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `user_namespace_authorization_get_user_namespace_authorizations_by_namespace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/namespaces/{namespace}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorizations',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_get_user_namespace_authorizations_by_user_id(self, user_id, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorizationsByUserId  # noqa: E501

        Gets a list of user namespace authorizations for the specified user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorizations_by_user_id(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_get_user_namespace_authorizations_by_user_id_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_get_user_namespace_authorizations_by_user_id_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_get_user_namespace_authorizations_by_user_id_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """getUserNamespaceAuthorizationsByUserId  # noqa: E501

        Gets a list of user namespace authorizations for the specified user.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_get_user_namespace_authorizations_by_user_id_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :return: UserNamespaceAuthorizations
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_get_user_namespace_authorizations_by_user_id" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `user_namespace_authorization_get_user_namespace_authorizations_by_user_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/userIds/{userId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorizations',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def user_namespace_authorization_update_user_namespace_authorization(self, user_id, namespace, user_namespace_authorization_update_request, **kwargs):  # noqa: E501
        """updateUserNamespaceAuthorization  # noqa: E501

        Updates an existing user namespace authorization by key. <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_update_user_namespace_authorization(user_id, namespace, user_namespace_authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :param UserNamespaceAuthorizationUpdateRequest user_namespace_authorization_update_request: the information needed to update the user namespace authorization (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.user_namespace_authorization_update_user_namespace_authorization_with_http_info(user_id, namespace, user_namespace_authorization_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.user_namespace_authorization_update_user_namespace_authorization_with_http_info(user_id, namespace, user_namespace_authorization_update_request, **kwargs)  # noqa: E501
            return data

    def user_namespace_authorization_update_user_namespace_authorization_with_http_info(self, user_id, namespace, user_namespace_authorization_update_request, **kwargs):  # noqa: E501
        """updateUserNamespaceAuthorization  # noqa: E501

        Updates an existing user namespace authorization by key. <p>Requires GRANT permission on namespace</p>  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.user_namespace_authorization_update_user_namespace_authorization_with_http_info(user_id, namespace, user_namespace_authorization_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: the user id (required)
        :param str namespace: the namespace (required)
        :param UserNamespaceAuthorizationUpdateRequest user_namespace_authorization_update_request: the information needed to update the user namespace authorization (required)
        :return: UserNamespaceAuthorization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['user_id', 'namespace', 'user_namespace_authorization_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method user_namespace_authorization_update_user_namespace_authorization" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'user_id' is set
        if ('user_id' not in local_var_params or
                local_var_params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `user_namespace_authorization_update_user_namespace_authorization`")  # noqa: E501
        # verify the required parameter 'namespace' is set
        if ('namespace' not in local_var_params or
                local_var_params['namespace'] is None):
            raise ValueError("Missing the required parameter `namespace` when calling `user_namespace_authorization_update_user_namespace_authorization`")  # noqa: E501
        # verify the required parameter 'user_namespace_authorization_update_request' is set
        if ('user_namespace_authorization_update_request' not in local_var_params or
                local_var_params['user_namespace_authorization_update_request'] is None):
            raise ValueError("Missing the required parameter `user_namespace_authorization_update_request` when calling `user_namespace_authorization_update_user_namespace_authorization`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'user_id' in local_var_params:
            path_params['userId'] = local_var_params['user_id']  # noqa: E501
        if 'namespace' in local_var_params:
            path_params['namespace'] = local_var_params['namespace']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'user_namespace_authorization_update_request' in local_var_params:
            body_params = local_var_params['user_namespace_authorization_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/userNamespaceAuthorizations/userIds/{userId}/namespaces/{namespace}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserNamespaceAuthorization',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.namespace_iam_role_authorization_api import NamespaceIAMRoleAuthorizationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestNamespaceIAMRoleAuthorizationApi(unittest.TestCase):
    """NamespaceIAMRoleAuthorizationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.namespace_iam_role_authorization_api.NamespaceIAMRoleAuthorizationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_namespace_iam_role_authorization_create_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_create_namespace_iam_role_authorization

        createNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_delete_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_delete_namespace_iam_role_authorization

        deleteNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorization

        getNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations

        getNamespaceIamRoleAuthorizations  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_iam_role_name

        getNamespaceIamRoleAuthorizationsByIamRoleName  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace(self):
        """Test case for namespace_iam_role_authorization_get_namespace_iam_role_authorizations_by_namespace

        getNamespaceIamRoleAuthorizationsByNamespace  # noqa: E501
        """
        pass

    def test_namespace_iam_role_authorization_update_namespace_iam_role_authorization(self):
        """Test case for namespace_iam_role_authorization_update_namespace_iam_role_authorization

        updateNamespaceIamRoleAuthorization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_unit_notification_registration_api import StorageUnitNotificationRegistrationApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStorageUnitNotificationRegistrationApi(unittest.TestCase):
    """StorageUnitNotificationRegistrationApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_unit_notification_registration_api.StorageUnitNotificationRegistrationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_unit_notification_registration_create_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_create_storage_unit_notification_registration

        createStorageUnitNotificationRegistration  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_delete_storage_unit_notification(self):
        """Test case for storage_unit_notification_registration_delete_storage_unit_notification

        deleteStorageUnitNotification  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registration

        getStorageUnitNotificationRegistration  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registrations_by_namespace

        getStorageUnitNotificationRegistrationsByNamespace  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter(self):
        """Test case for storage_unit_notification_registration_get_storage_unit_notification_registrations_by_notification_filter

        getStorageUnitNotificationRegistrationsByNotificationFilter  # noqa: E501
        """
        pass

    def test_storage_unit_notification_registration_update_storage_unit_notification_registration(self):
        """Test case for storage_unit_notification_registration_update_storage_unit_notification_registration

        updateStorageUnitNotificationRegistration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class JobSignalRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'receive_task_id': 'str',
        'parameters': 'list[Parameter]',
        's3_properties_location': 'S3PropertiesLocation'
    }

    attribute_map = {
        'id': 'id',
        'receive_task_id': 'receiveTaskId',
        'parameters': 'parameters',
        's3_properties_location': 's3PropertiesLocation'
    }

    def __init__(self, id=None, receive_task_id=None, parameters=None, s3_properties_location=None):  # noqa: E501
        """JobSignalRequest - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._receive_task_id = None
        self._parameters = None
        self._s3_properties_location = None
        self.discriminator = None

        self.id = id
        self.receive_task_id = receive_task_id
        if parameters is not None:
            self.parameters = parameters
        if s3_properties_location is not None:
            self.s3_properties_location = s3_properties_location

    @property
    def id(self):
        """Gets the id of this JobSignalRequest.  # noqa: E501

        The job id that uniquely identifies the previously submitted job  # noqa: E501

        :return: The id of this JobSignalRequest.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobSignalRequest.

        The job id that uniquely identifies the previously submitted job  # noqa: E501

        :param id: The id of this JobSignalRequest.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def receive_task_id(self):
        """Gets the receive_task_id of this JobSignalRequest.  # noqa: E501

        The task Id of the receive task in the job workflow to signal. The job must be waiting on this task at the time of this call                  # noqa: E501

        :return: The receive_task_id of this JobSignalRequest.  # noqa: E501
        :rtype: str
        """
        return self._receive_task_id

    @receive_task_id.setter
    def receive_task_id(self, receive_task_id):
        """Sets the receive_task_id of this JobSignalRequest.

        The task Id of the receive task in the job workflow to signal. The job must be waiting on this task at the time of this call                  # noqa: E501

        :param receive_task_id: The receive_task_id of this JobSignalRequest.  # noqa: E501
        :type: str
        """
        if receive_task_id is None:
            raise ValueError("Invalid value for `receive_task_id`, must not be `None`")  # noqa: E501

        self._receive_task_id = receive_task_id

    @property
    def parameters(self):
        """Gets the parameters of this JobSignalRequest.  # noqa: E501

        List of key/value pairs that will be made available to the job  # noqa: E501

        :return: The parameters of this JobSignalRequest.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this JobSignalRequest.

        List of key/value pairs that will be made available to the job  # noqa: E501

        :param parameters: The parameters of this JobSignalRequest.  # noqa: E501
        :type: list[Parameter]
        """

        self._parameters = parameters

    @property
    def s3_properties_location(self):
        """Gets the s3_properties_location of this JobSignalRequest.  # noqa: E501


        :return: The s3_properties_location of this JobSignalRequest.  # noqa: E501
        :rtype: S3PropertiesLocation
        """
        return self._s3_properties_location

    @s3_properties_location.setter
    def s3_properties_location(self, s3_properties_location):
        """Sets the s3_properties_location of this JobSignalRequest.


        :param s3_properties_location: The s3_properties_location of this JobSignalRequest.  # noqa: E501
        :type: S3PropertiesLocation
        """

        self._s3_properties_location = s3_properties_location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobSignalRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormatCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_format_usage': 'str',
        'business_object_format_file_type': 'str',
        'partition_key': 'str',
        'description': 'str',
        'document_schema': 'str',
        'document_schema_url': 'str',
        'attributes': 'list[Attribute]',
        'attribute_definitions': 'list[AttributeDefinition]',
        'enable_business_object_data_published_attributes_change_event_notification': 'bool',
        'schema': 'Schema',
        'relational_schema_name': 'str',
        'relational_table_name': 'str'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'business_object_format_file_type': 'businessObjectFormatFileType',
        'partition_key': 'partitionKey',
        'description': 'description',
        'document_schema': 'documentSchema',
        'document_schema_url': 'documentSchemaUrl',
        'attributes': 'attributes',
        'attribute_definitions': 'attributeDefinitions',
        'enable_business_object_data_published_attributes_change_event_notification': 'enableBusinessObjectDataPublishedAttributesChangeEventNotification',
        'schema': 'schema',
        'relational_schema_name': 'relationalSchemaName',
        'relational_table_name': 'relationalTableName'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_format_usage=None, business_object_format_file_type=None, partition_key=None, description=None, document_schema=None, document_schema_url=None, attributes=None, attribute_definitions=None, enable_business_object_data_published_attributes_change_event_notification=None, schema=None, relational_schema_name=None, relational_table_name=None):  # noqa: E501
        """BusinessObjectFormatCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_format_usage = None
        self._business_object_format_file_type = None
        self._partition_key = None
        self._description = None
        self._document_schema = None
        self._document_schema_url = None
        self._attributes = None
        self._attribute_definitions = None
        self._enable_business_object_data_published_attributes_change_event_notification = None
        self._schema = None
        self._relational_schema_name = None
        self._relational_table_name = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        self.business_object_format_usage = business_object_format_usage
        self.business_object_format_file_type = business_object_format_file_type
        self.partition_key = partition_key
        if description is not None:
            self.description = description
        if document_schema is not None:
            self.document_schema = document_schema
        if document_schema_url is not None:
            self.document_schema_url = document_schema_url
        if attributes is not None:
            self.attributes = attributes
        if attribute_definitions is not None:
            self.attribute_definitions = attribute_definitions
        if enable_business_object_data_published_attributes_change_event_notification is not None:
            self.enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification
        if schema is not None:
            self.schema = schema
        if relational_schema_name is not None:
            self.relational_schema_name = relational_schema_name
        if relational_table_name is not None:
            self.relational_table_name = relational_table_name

    @property
    def namespace(self):
        """Gets the namespace of this BusinessObjectFormatCreateRequest.  # noqa: E501

        The Namespace to which this Business Object Format is related  # noqa: E501

        :return: The namespace of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this BusinessObjectFormatCreateRequest.

        The Namespace to which this Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this BusinessObjectFormatCreateRequest.  # noqa: E501

        The name of the Business Object Definition to which this Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this BusinessObjectFormatCreateRequest.

        The name of the Business Object Definition to which this Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this BusinessObjectFormatCreateRequest.  # noqa: E501

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :return: The business_object_format_usage of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this BusinessObjectFormatCreateRequest.

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format. Does not have to be unique in the system, the Usage string is frequently shared across formats for multiple Business Object                   Definitions                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def business_object_format_file_type(self):
        """Gets the business_object_format_file_type of this BusinessObjectFormatCreateRequest.  # noqa: E501

        A File Type known to the system that describes the file type of data stored under this Business Object Format                  # noqa: E501

        :return: The business_object_format_file_type of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_file_type

    @business_object_format_file_type.setter
    def business_object_format_file_type(self, business_object_format_file_type):
        """Sets the business_object_format_file_type of this BusinessObjectFormatCreateRequest.

        A File Type known to the system that describes the file type of data stored under this Business Object Format                  # noqa: E501

        :param business_object_format_file_type: The business_object_format_file_type of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_file_type is None:
            raise ValueError("Invalid value for `business_object_format_file_type`, must not be `None`")  # noqa: E501

        self._business_object_format_file_type = business_object_format_file_type

    @property
    def partition_key(self):
        """Gets the partition_key of this BusinessObjectFormatCreateRequest.  # noqa: E501

        The partition key for this Business Object Format  # noqa: E501

        :return: The partition_key of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._partition_key

    @partition_key.setter
    def partition_key(self, partition_key):
        """Sets the partition_key of this BusinessObjectFormatCreateRequest.

        The partition key for this Business Object Format  # noqa: E501

        :param partition_key: The partition_key of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """
        if partition_key is None:
            raise ValueError("Invalid value for `partition_key`, must not be `None`")  # noqa: E501

        self._partition_key = partition_key

    @property
    def description(self):
        """Gets the description of this BusinessObjectFormatCreateRequest.  # noqa: E501

        Description of the Business Object Format  # noqa: E501

        :return: The description of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectFormatCreateRequest.

        Description of the Business Object Format  # noqa: E501

        :param description: The description of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def document_schema(self):
        """Gets the document_schema of this BusinessObjectFormatCreateRequest.  # noqa: E501

        The schema for document-style business object data registered with Herd.                   The schema allows the publisher to perform self-service validation of incoming data when registering business object data. It also allows                   the consumers to perform self-service downstream actions like hydrating objects when consuming business object data. The documentSchema is                   optional. Currently any documentSchema is accepted. Its content is not validated                  # noqa: E501

        :return: The document_schema of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_schema

    @document_schema.setter
    def document_schema(self, document_schema):
        """Sets the document_schema of this BusinessObjectFormatCreateRequest.

        The schema for document-style business object data registered with Herd.                   The schema allows the publisher to perform self-service validation of incoming data when registering business object data. It also allows                   the consumers to perform self-service downstream actions like hydrating objects when consuming business object data. The documentSchema is                   optional. Currently any documentSchema is accepted. Its content is not validated                  # noqa: E501

        :param document_schema: The document_schema of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """

        self._document_schema = document_schema

    @property
    def document_schema_url(self):
        """Gets the document_schema_url of this BusinessObjectFormatCreateRequest.  # noqa: E501

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL                  # noqa: E501

        :return: The document_schema_url of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_schema_url

    @document_schema_url.setter
    def document_schema_url(self, document_schema_url):
        """Sets the document_schema_url of this BusinessObjectFormatCreateRequest.

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL                  # noqa: E501

        :param document_schema_url: The document_schema_url of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """

        self._document_schema_url = document_schema_url

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectFormatCreateRequest.  # noqa: E501

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :return: The attributes of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectFormatCreateRequest.

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    @property
    def attribute_definitions(self):
        """Gets the attribute_definitions of this BusinessObjectFormatCreateRequest.  # noqa: E501

        List of attribute definitions (for storage of custom user-defined metadata with objects) which are required to be specified                   when registering Business Object Data against this format. This list will define which metadata must be specified, but additional metadata can                   still be registered which is not specified in this list. The metadata (attributes) will allow applications to store custom data with                   registered data for use by consumers of the data                  # noqa: E501

        :return: The attribute_definitions of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: list[AttributeDefinition]
        """
        return self._attribute_definitions

    @attribute_definitions.setter
    def attribute_definitions(self, attribute_definitions):
        """Sets the attribute_definitions of this BusinessObjectFormatCreateRequest.

        List of attribute definitions (for storage of custom user-defined metadata with objects) which are required to be specified                   when registering Business Object Data against this format. This list will define which metadata must be specified, but additional metadata can                   still be registered which is not specified in this list. The metadata (attributes) will allow applications to store custom data with                   registered data for use by consumers of the data                  # noqa: E501

        :param attribute_definitions: The attribute_definitions of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: list[AttributeDefinition]
        """

        self._attribute_definitions = attribute_definitions

    @property
    def enable_business_object_data_published_attributes_change_event_notification(self):
        """Gets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatCreateRequest.  # noqa: E501

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :return: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_business_object_data_published_attributes_change_event_notification

    @enable_business_object_data_published_attributes_change_event_notification.setter
    def enable_business_object_data_published_attributes_change_event_notification(self, enable_business_object_data_published_attributes_change_event_notification):
        """Sets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatCreateRequest.

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :param enable_business_object_data_published_attributes_change_event_notification: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: bool
        """

        self._enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification

    @property
    def schema(self):
        """Gets the schema of this BusinessObjectFormatCreateRequest.  # noqa: E501


        :return: The schema of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this BusinessObjectFormatCreateRequest.


        :param schema: The schema of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: Schema
        """

        self._schema = schema

    @property
    def relational_schema_name(self):
        """Gets the relational_schema_name of this BusinessObjectFormatCreateRequest.  # noqa: E501

        Contains Relational Schema Name if the Format is of type Relational Table  # noqa: E501

        :return: The relational_schema_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._relational_schema_name

    @relational_schema_name.setter
    def relational_schema_name(self, relational_schema_name):
        """Sets the relational_schema_name of this BusinessObjectFormatCreateRequest.

        Contains Relational Schema Name if the Format is of type Relational Table  # noqa: E501

        :param relational_schema_name: The relational_schema_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """

        self._relational_schema_name = relational_schema_name

    @property
    def relational_table_name(self):
        """Gets the relational_table_name of this BusinessObjectFormatCreateRequest.  # noqa: E501

        Contains Relational Table Name if the Format is of type Relational Table  # noqa: E501

        :return: The relational_table_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._relational_table_name

    @relational_table_name.setter
    def relational_table_name(self, relational_table_name):
        """Sets the relational_table_name of this BusinessObjectFormatCreateRequest.

        Contains Relational Table Name if the Format is of type Relational Table  # noqa: E501

        :param relational_table_name: The relational_table_name of this BusinessObjectFormatCreateRequest.  # noqa: E501
        :type: str
        """

        self._relational_table_name = relational_table_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormatCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormatUpdateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        'document_schema': 'str',
        'document_schema_url': 'str',
        'attributes': 'list[Attribute]',
        'schema': 'Schema'
    }

    attribute_map = {
        'description': 'description',
        'document_schema': 'documentSchema',
        'document_schema_url': 'documentSchemaUrl',
        'attributes': 'attributes',
        'schema': 'schema'
    }

    def __init__(self, description=None, document_schema=None, document_schema_url=None, attributes=None, schema=None):  # noqa: E501
        """BusinessObjectFormatUpdateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._description = None
        self._document_schema = None
        self._document_schema_url = None
        self._attributes = None
        self._schema = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if document_schema is not None:
            self.document_schema = document_schema
        if document_schema_url is not None:
            self.document_schema_url = document_schema_url
        if attributes is not None:
            self.attributes = attributes
        if schema is not None:
            self.schema = schema

    @property
    def description(self):
        """Gets the description of this BusinessObjectFormatUpdateRequest.  # noqa: E501

        Description of the Business Object Format  # noqa: E501

        :return: The description of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BusinessObjectFormatUpdateRequest.

        Description of the Business Object Format  # noqa: E501

        :param description: The description of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def document_schema(self):
        """Gets the document_schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501

        The schema for document-style business object data registered with Herd. The schema allows the publisher to perform                   self-service validation of incoming data when registering business object data. It also allows the consumers to perform self-service                   downstream actions like hydrating objects when consuming business object data. The documentSchema is optional. Currently any documentSchema is                   accepted. Its content is not validated                  # noqa: E501

        :return: The document_schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_schema

    @document_schema.setter
    def document_schema(self, document_schema):
        """Sets the document_schema of this BusinessObjectFormatUpdateRequest.

        The schema for document-style business object data registered with Herd. The schema allows the publisher to perform                   self-service validation of incoming data when registering business object data. It also allows the consumers to perform self-service                   downstream actions like hydrating objects when consuming business object data. The documentSchema is optional. Currently any documentSchema is                   accepted. Its content is not validated                  # noqa: E501

        :param document_schema: The document_schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :type: str
        """

        self._document_schema = document_schema

    @property
    def document_schema_url(self):
        """Gets the document_schema_url of this BusinessObjectFormatUpdateRequest.  # noqa: E501

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL and teams can then access the URL                  # noqa: E501

        :return: The document_schema_url of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_schema_url

    @document_schema_url.setter
    def document_schema_url(self, document_schema_url):
        """Sets the document_schema_url of this BusinessObjectFormatUpdateRequest.

        An optional URL of the documentSchema to an externally hosted XSD or JSON. Herd will not access this URL,                   it will simply store and retrieve the URL and teams can then access the URL                  # noqa: E501

        :param document_schema_url: The document_schema_url of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :type: str
        """

        self._document_schema_url = document_schema_url

    @property
    def attributes(self):
        """Gets the attributes of this BusinessObjectFormatUpdateRequest.  # noqa: E501

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :return: The attributes of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :rtype: list[Attribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this BusinessObjectFormatUpdateRequest.

        Custom user-defined metadata associated with this Business Object Format. \"name\" is the attribute name (i.e. the key) and                   \"value\" is the attribute value                  # noqa: E501

        :param attributes: The attributes of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :type: list[Attribute]
        """

        self._attributes = attributes

    @property
    def schema(self):
        """Gets the schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501


        :return: The schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :rtype: Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """Sets the schema of this BusinessObjectFormatUpdateRequest.


        :param schema: The schema of this BusinessObjectFormatUpdateRequest.  # noqa: E501
        :type: Schema
        """

        self._schema = schema

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormatUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinitionInstanceTypeConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'instance_type': 'str',
        'weighted_capacity': 'int',
        'bid_price': 'str',
        'bid_price_as_percentage_of_on_demand_price': 'str',
        'ebs_configuration': 'EmrClusterDefinitionEbsConfiguration',
        'configurations': 'list[EmrClusterDefinitionConfiguration]'
    }

    attribute_map = {
        'instance_type': 'instanceType',
        'weighted_capacity': 'weightedCapacity',
        'bid_price': 'bidPrice',
        'bid_price_as_percentage_of_on_demand_price': 'bidPriceAsPercentageOfOnDemandPrice',
        'ebs_configuration': 'ebsConfiguration',
        'configurations': 'configurations'
    }

    def __init__(self, instance_type=None, weighted_capacity=None, bid_price=None, bid_price_as_percentage_of_on_demand_price=None, ebs_configuration=None, configurations=None):  # noqa: E501
        """EmrClusterDefinitionInstanceTypeConfig - a model defined in OpenAPI"""  # noqa: E501

        self._instance_type = None
        self._weighted_capacity = None
        self._bid_price = None
        self._bid_price_as_percentage_of_on_demand_price = None
        self._ebs_configuration = None
        self._configurations = None
        self.discriminator = None

        if instance_type is not None:
            self.instance_type = instance_type
        if weighted_capacity is not None:
            self.weighted_capacity = weighted_capacity
        if bid_price is not None:
            self.bid_price = bid_price
        if bid_price_as_percentage_of_on_demand_price is not None:
            self.bid_price_as_percentage_of_on_demand_price = bid_price_as_percentage_of_on_demand_price
        if ebs_configuration is not None:
            self.ebs_configuration = ebs_configuration
        if configurations is not None:
            self.configurations = configurations

    @property
    def instance_type(self):
        """Gets the instance_type of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501

        An EC2 instance type, such as 'm3.xlarge'.                  # noqa: E501

        :return: The instance_type of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type):
        """Sets the instance_type of this EmrClusterDefinitionInstanceTypeConfig.

        An EC2 instance type, such as 'm3.xlarge'.                  # noqa: E501

        :param instance_type: The instance_type of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def weighted_capacity(self):
        """Gets the weighted_capacity of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501

        The number of units that a provisioned instance of this type provides toward fulfilling the target capacities                   defined in InstanceFleetConfig. This value is 1 for a master instance fleet, and must be greater than 0                   for core and task instance fleets                  # noqa: E501

        :return: The weighted_capacity of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: int
        """
        return self._weighted_capacity

    @weighted_capacity.setter
    def weighted_capacity(self, weighted_capacity):
        """Sets the weighted_capacity of this EmrClusterDefinitionInstanceTypeConfig.

        The number of units that a provisioned instance of this type provides toward fulfilling the target capacities                   defined in InstanceFleetConfig. This value is 1 for a master instance fleet, and must be greater than 0                   for core and task instance fleets                  # noqa: E501

        :param weighted_capacity: The weighted_capacity of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: int
        """

        self._weighted_capacity = weighted_capacity

    @property
    def bid_price(self):
        """Gets the bid_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501

        The bid price for each EC2 Spot instance type as defined by InstanceType. Expressed in USD. If neither BidPrice nor                   BidPriceAsPercentageOfOnDemandPrice is provided, BidPriceAsPercentageOfOnDemandPrice defaults to 100%                  # noqa: E501

        :return: The bid_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: str
        """
        return self._bid_price

    @bid_price.setter
    def bid_price(self, bid_price):
        """Sets the bid_price of this EmrClusterDefinitionInstanceTypeConfig.

        The bid price for each EC2 Spot instance type as defined by InstanceType. Expressed in USD. If neither BidPrice nor                   BidPriceAsPercentageOfOnDemandPrice is provided, BidPriceAsPercentageOfOnDemandPrice defaults to 100%                  # noqa: E501

        :param bid_price: The bid_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: str
        """

        self._bid_price = bid_price

    @property
    def bid_price_as_percentage_of_on_demand_price(self):
        """Gets the bid_price_as_percentage_of_on_demand_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501

        The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by InstanceType. Expressed as a number                   between 0 and 1000 (for example, 20 specifies 20%). If neither BidPrice nor BidPriceAsPercentageOfOnDemandPrice is provided,                   BidPriceAsPercentageOfOnDemandPrice defaults to 100%                  # noqa: E501

        :return: The bid_price_as_percentage_of_on_demand_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: str
        """
        return self._bid_price_as_percentage_of_on_demand_price

    @bid_price_as_percentage_of_on_demand_price.setter
    def bid_price_as_percentage_of_on_demand_price(self, bid_price_as_percentage_of_on_demand_price):
        """Sets the bid_price_as_percentage_of_on_demand_price of this EmrClusterDefinitionInstanceTypeConfig.

        The bid price, as a percentage of On-Demand price, for each EC2 Spot instance as defined by InstanceType. Expressed as a number                   between 0 and 1000 (for example, 20 specifies 20%). If neither BidPrice nor BidPriceAsPercentageOfOnDemandPrice is provided,                   BidPriceAsPercentageOfOnDemandPrice defaults to 100%                  # noqa: E501

        :param bid_price_as_percentage_of_on_demand_price: The bid_price_as_percentage_of_on_demand_price of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: str
        """

        self._bid_price_as_percentage_of_on_demand_price = bid_price_as_percentage_of_on_demand_price

    @property
    def ebs_configuration(self):
        """Gets the ebs_configuration of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501


        :return: The ebs_configuration of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: EmrClusterDefinitionEbsConfiguration
        """
        return self._ebs_configuration

    @ebs_configuration.setter
    def ebs_configuration(self, ebs_configuration):
        """Sets the ebs_configuration of this EmrClusterDefinitionInstanceTypeConfig.


        :param ebs_configuration: The ebs_configuration of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: EmrClusterDefinitionEbsConfiguration
        """

        self._ebs_configuration = ebs_configuration

    @property
    def configurations(self):
        """Gets the configurations of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501

        A configuration classification that applies when provisioning cluster instances, which can include configurations for                   applications and software that run on the cluster                  # noqa: E501

        :return: The configurations of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :rtype: list[EmrClusterDefinitionConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """Sets the configurations of this EmrClusterDefinitionInstanceTypeConfig.

        A configuration classification that applies when provisioning cluster instances, which can include configurations for                   applications and software that run on the cluster                  # noqa: E501

        :param configurations: The configurations of this EmrClusterDefinitionInstanceTypeConfig.  # noqa: E501
        :type: list[EmrClusterDefinitionConfiguration]
        """

        self._configurations = configurations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinitionInstanceTypeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
